@@ -14,8 +14,11 @@
 #'
 #' set.seed(123)
 #'
-#' # data
-#' m1 <- dplyr::tibble(
+#' # generate data
+#' library(dplyr)
+#' library(purrr)
+#'
+#' m1 <- tibble(
 #'   v1 = c(1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 3, 3, 3, 3, 3, 4, 5, 6),
 #'   v2 = c(1, 2, 1, 1, 1, 1, 2, 1, 2, 1, 3, 4, 3, 3, 3, 4, 6, 5),
 #'   v3 = c(3, 3, 3, 3, 3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 5, 4, 6),
@@ -25,11 +28,11 @@
 #' )
 #'
 #' # new data
-#' m2 <- purrr::map_dfr(m1, rev)
+#' m2 <- map_dfr(m1, rev)
 #'
 #' # factor analysis objects
-#' fit1 <- stats::factanal(m1, factors = 3, scores = "Bartlett")
-#' fit2 <- stats::factanal(m1, factors = 3, scores = "regression")
+#' fit1 <- factanal(m1, factors = 3, scores = "Bartlett")
+#' fit2 <- factanal(m1, factors = 3, scores = "regression")
 #'
 #' # tidying the object
 #' tidy(fit1)
@@ -42,13 +45,13 @@
 #' # augmented dataframe (with new data)
 #' augment(fit1, data = m2)
 #' augment(fit2, data = m2)
+#'
 #' @aliases factanal_tidiers
 #' @export
 #' @seealso [tidy()], [stats::factanal()]
 #' @family factanal tidiers
 
 tidy.factanal <- function(x, ...) {
-
   # as.matrix() causes this to break. unsure if this is a hack or appropriate
   loadings <- stats::loadings(x)
   class(loadings) <- "matrix"
@@ -87,6 +90,8 @@ tidy.factanal <- function(x, ...) {
 #' @seealso [augment()], [stats::factanal()]
 #' @family factanal tidiers
 augment.factanal <- function(x, data, ...) {
+  check_ellipses("newdata", "augment", "factanal", ...)
+
   scores <- x$scores
 
   # Check scores were computed
@@ -154,7 +159,6 @@ augment.factanal <- function(x, data, ...) {
 #' @seealso [glance()], [stats::factanal()]
 #' @family factanal tidiers
 glance.factanal <- function(x, ...) {
-
   # Compute total variance accounted for by all factors
   loadings <- stats::loadings(x)
   class(loadings) <- "matrix"
