@@ -12,11 +12,11 @@ rename2 <- function(.data, ...) {
   rename(.data, !!!present)
 }
 
-exponentiate <- function(data) {
-  data <- mutate_at(data, vars(estimate), exp)
+exponentiate <- function(data, col = "estimate") {
+  data <- data %>% mutate(across(all_of(col), exp))
 
   if ("conf.low" %in% colnames(data)) {
-    data <- mutate_at(data, vars(conf.low, conf.high), exp)
+    data <- data %>% mutate(across(c(conf.low, conf.high), exp))
   }
 
   data
@@ -34,11 +34,14 @@ exponentiate <- function(data) {
 #' @return A `tibble` potentially with a `.rownames` column
 #' @noRd
 #'
-as_augment_tibble <- function(data) {
 
+
+as_augment_tibble <- function(data) {
   if (inherits(data, "matrix") & is.null(colnames(data))) {
-    stop("The supplied `data`/`newdata` argument was an unnamed matrix. ",
-         "Please supply a matrix or dataframe with column names.")
+    stop(
+      "The supplied `data`/`newdata` argument was an unnamed matrix. ",
+      "Please supply a matrix or dataframe with column names."
+    )
   }
 
   tryCatch(
@@ -52,15 +55,26 @@ as_augment_tibble <- function(data) {
   )
 
   if (has_rownames(data)) {
-    df <- tibble::add_column(df, 
-                             .rownames = rownames(data), 
-                             .before = TRUE)
+    df <- tibble::add_column(df,
+      .rownames = rownames(data),
+      .before = TRUE
+    )
   }
   df
 }
 
+# adapted from ps:::is_cran_check()
+is_cran_check <- function() {
+  if (identical(Sys.getenv("NOT_CRAN"), "true")) {
+    FALSE
+  }
+  else {
+    Sys.getenv("_R_CHECK_PACKAGE_NAME_", "") != ""
+  }
+}
+
 #' Convert a data.frame or matrix to a tibble
-#' 
+#'
 #' This function is meant for use inside `tidy.*` methods.
 #'
 #' @param x a data.frame or matrix
@@ -71,13 +85,12 @@ as_augment_tibble <- function(data) {
 #' names assigned
 #' @noRd
 as_tidy_tibble <- function(x, new_names = NULL, new_column = "term") {
-  
   if (!is.null(new_names) && length(new_names) != ncol(x)) {
     stop("newnames must be NULL or have length equal to number of columns")
   }
 
   ret <- x
-  
+
   # matrices will take setNames by element, so rename conditionally
   if (!is.null(new_names)) {
     if (inherits(x, "data.frame")) {
@@ -86,31 +99,32 @@ as_tidy_tibble <- function(x, new_names = NULL, new_column = "term") {
       colnames(ret) <- new_names
     }
   }
-  
+
   if (all(rownames(x) == seq_len(nrow(x)))) {
     # don't need to move rownames into a new column
     tibble::as_tibble(ret)
   } else {
     # don't use tibble rownames to col because of name repairing
-    dplyr::bind_cols(!!new_column := rownames(x), 
-                     tibble::as_tibble(ret))
+    dplyr::bind_cols(
+      !!new_column := rownames(x),
+      tibble::as_tibble(ret)
+    )
   }
 }
 
 #' @param x A list of data.frames or matrices
 #' @param ... Extra arguments to pass to as_tidy_tibble
-#' @param id_column The name of the column giving the name of each 
+#' @param id_column The name of the column giving the name of each
 #' element in `x`
 #' @noRd
-map_as_tidy_tibble <- function(x, 
-                                     ..., 
-                                     id_column = "component") {
-  
-  purrr::map_df(x, 
-                as_tidy_tibble, 
-                ...,
-                .id = id_column)
-  
+map_as_tidy_tibble <- function(x,
+                               ...,
+                               id_column = "component") {
+  purrr::map_df(x,
+    as_tidy_tibble,
+    ...,
+    .id = id_column
+  )
 }
 
 # copied from modeltests. re-export if at some we Import modeltests rather
@@ -122,48 +136,51 @@ has_rownames <- function(df) {
   any(rownames(df) != as.character(1:nrow(df)))
 }
 
-na_types_dict <- list("r" = NA_real_,
-                      "i" = rlang::na_int,
-                      "c" = NA_character_,
-                      "l" = rlang::na_lgl)
+na_types_dict <- list(
+  "r" = NA_real_,
+  "i" = rlang::na_int,
+  "c" = NA_character_,
+  "l" = rlang::na_lgl
+)
 
-# A function that converts a string to a vector of NA types.
+# a function that converts a string to a vector of NA types.
 # e.g. "rri" -> c(NA_real_, NA_real_, rlang::na_int)
 parse_na_types <- function(s) {
-  
   positions <- purrr::map(
-    stringr::str_split(s, pattern = ""), 
+    stringr::str_split(s, pattern = ""),
     match,
     table = names(na_types_dict)
   ) %>%
     unlist()
-  
+
   na_types_dict[positions] %>%
     unlist() %>%
     unname()
 }
 
-# A function that, given named arguments, will make a one-row
+# a function that, given named arguments, will make a one-row
 # tibble, switching out NULLs for the appropriate NA type.
 as_glance_tibble <- function(..., na_types) {
-  
   cols <- list(...)
-  
+
   if (length(cols) != stringr::str_length(na_types)) {
     stop(
       "The number of columns provided does not match the number of ",
       "column types provided."
     )
   }
-  
+
   na_types_long <- parse_na_types(na_types)
-  
-  entries <- purrr::map2(cols, 
-                         na_types_long, 
-                         function(.x, .y) {if (length(.x) == 0) .y else .x})
-  
+
+  entries <- purrr::map2(
+    cols,
+    na_types_long,
+    function(.x, .y) {
+      if (length(.x) == 0) .y else .x
+    }
+  )
+
   tibble::as_tibble_row(entries)
-  
 }
 
 # strip rownames from a data frame
@@ -176,11 +193,11 @@ unrowname <- function(x) {
 #' an augment call
 #'
 #' `augment_columns` is intended for use in the internals of `augment` methods
-#' only and is exported for developers extending the broom package. Please 
-#' instead use [augment()] to appropriately make use of the functionality 
+#' only and is exported for developers extending the broom package. Please
+#' instead use [augment()] to appropriately make use of the functionality
 #' in `augment_columns()`.
 #'
-#' Note that, in the case that a `residuals()` or `influence()` generic is 
+#' Note that, in the case that a `residuals()` or `influence()` generic is
 #' not implemented for the supplied model `x`, the function will fail quietly.
 #'
 #' @param x a model
@@ -223,7 +240,7 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
   if ("panelmodel" %in% class(x)) {
     # work around for panel models (plm)
     # stat::predict() returns wrong fitted values when applied to random or
-    # fixed effect panel models [plm(..., model="random"), plm(, ..., model="pooling")]
+    # fixed effect panel models [plm(..., model="random"), plm(, ..., model="within")]
     # It works only for pooled OLS models (plm( ..., model="pooling"))
     pred <- model.frame(x)[, 1] - residuals(x)
   } else {
@@ -282,7 +299,7 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
 
     original <- data
 
-    if (class(na_action) == "exclude") {
+    if (inherits(na_action, "exclude")) {
       # check if values are missing
       if (length(stats::residuals(x)) > nrow(data)) {
         warning(
@@ -300,7 +317,7 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
     # no NAs were left out; we can simply recombine
     original <- as_augment_tibble(original)
     return(as_tibble(cbind(original, ret)))
-  } else if (class(na_action) == "omit") {
+  } else if (inherits(na_action, "omit")) {
     # if the option is "omit", drop those rows from the data
     original <- as_augment_tibble(original)
     original <- original[-na_action, ]
@@ -324,8 +341,22 @@ augment_columns <- function(x, data, newdata = NULL, type, type.predict = type,
   as_tibble(ret)
 }
 
-response <- function(object, newdata = NULL) {
-  model.response(model.frame(terms(object), data = newdata, na.action = na.pass))
+response <- function(object, newdata = NULL, has_response) {
+  if (!has_response) {
+    return(NULL)
+  }
+
+  res <-
+    tryCatch(
+      model.response(model.frame(terms(object), data = newdata, na.action = na.pass)),
+      error = function(e) NULL
+    )
+
+  if (is.null(res)) {
+    res <- model.response(model.frame(object))
+  }
+
+  res
 }
 
 data_error <- function(cnd) {
@@ -371,11 +402,18 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
   df <- if (passed_newdata) newdata else data
   df <- as_augment_tibble(df)
   # interval <- match.arg(interval)
-  # Check if response variable is in newdata:
-  response_var_in_newdata <- x$call %>%
-    all.vars() %>%
-    .[[1]] %>%
-    is.element(names(df))
+  # check if response variable is in newdata, if relevant:
+  if (!is.null(x$terms) & inherits(x$terms, "formula")) {
+    has_response <-
+      # TRUE if response includes a function call and is in column names,
+      # usually with no `data` or `newdata` supplied,
+      # and `data` defaults to `model_frame(x)`
+      rlang::as_label(rlang::f_lhs(x$terms)) %in% names(df) ||
+        # TRUE if the response variable itself is in column names
+        all.vars(x$terms)[1] %in% names(df)
+  } else {
+    has_response <- FALSE
+  }
 
   # NOTE: It is important use predict(x, newdata = newdata) rather than
   # predict(x, newdata = df). This is to avoid an edge case breakage
@@ -391,31 +429,30 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
 
   # This helper *should not* be used for predict methods that do not have
   # an na.pass argument
-  
+
   if (.se_fit) {
     pred_obj <- predict(x, newdata = newdata, na.action = na.pass, se.fit = .se_fit, interval = interval, ...)
-    if (is.null(interval) || interval=="none") {
+    if (is.null(interval) || interval == "none") {
       df$.fitted <- pred_obj$fit %>% unname()
     } else {
       df$.fitted <- pred_obj$fit[, "fit"]
       df$.lower <- pred_obj$fit[, "lwr"]
       df$.upper <- pred_obj$fit[, "upr"]
     }
-    
+
     # a couple possible names for the standard error element of the list
     # se.fit: lm, glm
     # se: loess
     se_idx <- which(names(pred_obj) %in% c("se.fit", "se"))
     df$.se.fit <- pred_obj[[se_idx]]
-    
-  } else if (!is.null(interval) && interval!="none") {
+  } else if (!is.null(interval) && interval != "none") {
     pred_obj <- predict(x, newdata = newdata, na.action = na.pass, se.fit = FALSE, interval = interval, ...)
     df$.fitted <- pred_obj[, "fit"]
     df$.lower <- pred_obj[, "lwr"]
     df$.upper <- pred_obj[, "upr"]
   } else if (passed_newdata) {
-    if (is.null(interval) || interval=="none") {
-      df$.fitted <- predict(x, newdata = newdata, na.action = na.pass, ...) %>% 
+    if (is.null(interval) || interval == "none") {
+      df$.fitted <- predict(x, newdata = newdata, na.action = na.pass, ...) %>%
         unname()
     } else {
       pred_obj <- predict(x, newdata = newdata, na.action = na.pass, interval = interval, ...)
@@ -424,8 +461,8 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
       df$.upper <- pred_obj$fit[, "upr"]
     }
   } else {
-    if (is.null(interval) || interval=="none") {
-      df$.fitted <- predict(x, na.action = na.pass, ...) %>% 
+    if (is.null(interval) || interval == "none") {
+      df$.fitted <- predict(x, na.action = na.pass, ...) %>%
         unname()
     } else {
       pred_obj <- predict(x, newdata = newdata, na.action = na.pass, interval = interval, ...)
@@ -435,10 +472,10 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
     }
   }
 
-  resp <- safe_response(x, df)
+  resp <- safe_response(x, df, has_response)
 
   if (!is.null(resp) && is.numeric(resp)) {
-    df$.resid <- (resp - df$.fitted) %>% unname() 
+    df$.resid <- (resp - df$.fitted) %>% unname()
   }
 
   df
@@ -447,7 +484,6 @@ augment_newdata <- function(x, data, newdata, .se_fit, interval = NULL, ...) {
 # this exists to avoid the single predictor gotcha
 # this version adds a terms column
 broom_confint <- function(x, ...) {
-
   # warn on arguments silently being ignored
   ellipsis::check_dots_used()
   ci <- suppressMessages(confint(x, ...))
@@ -466,7 +502,6 @@ broom_confint <- function(x, ...) {
 
 # this version adds a terms column
 broom_confint_terms <- function(x, ...) {
-
   # warn on arguments silently being ignored
   ellipsis::check_dots_used()
   ci <- suppressMessages(confint(x, ...))
@@ -479,26 +514,29 @@ broom_confint_terms <- function(x, ...) {
     rownames(ci) <- names(coef(x))[1]
   }
 
-  ci <- as_tibble(ci, rownames = "term")
+  ci <- as_tibble(ci, rownames = "term", .name_repair = "minimal")
   names(ci) <- c("term", "conf.low", "conf.high")
   ci
 }
 
 # warn when models subclasses glm/lm and do not have their own dedicated tidiers.
-warn_on_subclass <- function(x) {
+warn_on_subclass <- function(x, tidier) {
   if (length(class(x)) > 1 && class(x)[1] != "glm") {
     subclass <- class(x)[1]
     dispatched_method <- class(x)[class(x) %in% c("glm", "lm")][1]
-    
-    warning(
-      "Tidiers for objects of class ", 
-      subclass, 
-      " are not maintained by the broom team, and are only supported through ",
-      "the ", 
-      dispatched_method, 
-      " tidier method. Please be cautious in interpreting and reporting ",
-      "broom output.",
-      call. = FALSE
+
+    rlang::warn(
+      paste0(
+        "The `", tidier, "()` method for objects of class `",
+        subclass,
+        "` is not maintained by the broom team, and is only supported through ",
+        "the `",
+        dispatched_method,
+        "` tidier method. Please be cautious in interpreting and reporting ",
+        "broom output.\n"
+      ),
+      .frequency = "once",
+      .frequency_id = subclass
     )
   }
 }
@@ -515,6 +553,7 @@ globalVariables(
     ".tau",
     "aic",
     "alternative",
+    "AME",
     "bic",
     "chosen",
     "ci.lower",
@@ -560,6 +599,7 @@ globalVariables(
     "lhs",
     "lm",
     "loading",
+    "lower",
     "method",
     "Method",
     "N",
@@ -569,6 +609,7 @@ globalVariables(
     "objs",
     "obs",
     "op",
+    "p",
     "p.value",
     "packageVersion",
     "PC",
@@ -584,6 +625,7 @@ globalVariables(
     "rowname",
     "rstudent",
     "se",
+    "SE",
     "series",
     "Slope",
     "stat",
@@ -596,17 +638,31 @@ globalVariables(
     "tau2.del",
     "term",
     "type",
+    "upper",
     "value",
     "Var1",
     "Var2",
     "variable",
     "wald.test",
     "weight",
+    "where",
     "y",
     "z"
   )
 )
 
-load_ggplot <- function(){
-  ggplot2::ggplot
+# a gentler version of dots checking that, given a dots entry to
+# look for, will warn if that entry is in the dots.
+# in broom, this is used for exponentiate (in tidy) and newdata (in augment).
+check_ellipses <- function(arg, fn, cls, ...) {
+  dots <- rlang::enquos(...)
+
+  if (arg %in% names(dots)) {
+    rlang::warn(paste0(
+      "The `", arg, "` argument is not supported in the `", fn,
+      "()` method for `", cls, "` objects and will be ignored."
+    ))
+  }
+
+  invisible(NULL)
 }
