@@ -15,26 +15,26 @@
 #'   term was used to model either the `"mean"` or `"precision"`. Here the
 #'   precision is the inverse of the variance, often referred to as `phi`.
 #'   At least one term will have been used to model the precision `phi`.
-#' 
+#'
 #'   The `vars` package does not include a `confint` method and does not report
 #'   confidence intervals for `varest` objects. Setting the `tidy` argument
 #'   `conf.int = TRUE` will return a warning.
 #'
 #' @examplesIf rlang::is_installed("vars")
-#' 
+#'
 #' # load libraries for models and data
 #' library(vars)
-#' 
+#'
 #' # load data
 #' data("Canada", package = "vars")
-#' 
+#'
 #' # fit models
 #' mod <- VAR(Canada, p = 1, type = "both")
-#' 
+#'
 #' # summarize model fit with tidiers
 #' tidy(mod)
 #' glance(mod)
-#' 
+#'
 #' @export
 #' @seealso [tidy()], [vars::VAR()]
 #' @family vars tidiers
@@ -50,7 +50,7 @@ tidy.varest <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
   s <- summary(x)
 
   ret <- list()
-  
+
   for (v in names(s$varresult)) {
     ret[[v]] <- as_tidy_tibble(
       s$varresult[[1]]$coefficients,
@@ -58,9 +58,9 @@ tidy.varest <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
     )
     ret[[v]]$group <- v
   }
-  
+
   ret <- dplyr::bind_rows(ret) %>%
-        dplyr::relocate(group, 1)
+    dplyr::relocate(group, 1)
 
   ret
 }
@@ -88,5 +88,6 @@ glance.varest <- function(x, ...) {
     logLik = s$logLik,
     nobs = x$obs,
     n = x$totobs,
-    na_types = "riii")
+    na_types = "riii"
+  )
 }
