@@ -25,7 +25,7 @@ test_that("tidy.durbinWatsonTest", {
 
 test_that("tidy.leveneTest", {
   skip_if_not_installed("carData")
-  
+
   mod1 <- with(carData::Moore, leveneTest(conformity, fcategory))
   mod2 <- with(carData::Moore, leveneTest(conformity, interaction(fcategory, partner.status)))
   mod3 <- leveneTest(conformity ~ fcategory * partner.status, data = Moore)
@@ -42,22 +42,23 @@ test_that("tidy.leveneTest", {
     tidy(mod3),
     tidy(mod4),
     tidy(mod5),
-    tidy(mod6))
+    tidy(mod6)
+  )
 })
 
 test_that("tidy car::Anova glm", {
   fit <- glm(am ~ mpg, mtcars, family = "binomial")
   fit2 <- glm(am ~ mpg + wt, mtcars, family = "binomial")
-  
+
   car_anova <- car::Anova(fit, test.statistic = "LR")
   car_anova2 <- car::Anova(fit2, test.statistic = "LR")
-  
+
   td <- tidy(car_anova)
   td2 <- tidy(car_anova2)
 
   check_tidy_output(td)
   check_tidy_output(td2)
-  
+
   check_dims(td, expected_rows = 1, expected_cols = 4)
   check_dims(td2, expected_rows = 2, expected_cols = 4)
 })
@@ -66,7 +67,7 @@ test_that("tidy car::Anova coxph", {
   fit <- coxph(Surv(time, status) ~ differ, data = colon)
   fit2 <- coxph(Surv(time) ~ differ, data = colon)
   fit3 <- coxph(Surv(time) ~ differ + extent, data = colon)
-  
+
   car_anova_coxph <- car::Anova(fit)
   car_anova_coxph2 <- car::Anova(fit2)
   car_anova_coxph3 <- car::Anova(fit3)
@@ -74,11 +75,11 @@ test_that("tidy car::Anova coxph", {
   td <- tidy(car_anova_coxph)
   td2 <- tidy(car_anova_coxph2)
   td3 <- tidy(car_anova_coxph3)
-  
+
   check_tidy_output(td)
   check_tidy_output(td2)
   check_tidy_output(td3)
-    
+
   check_dims(td, expected_rows = 2, expected_cols = 5)
   check_dims(td2, expected_rows = 2, expected_cols = 5)
   check_dims(td3, expected_rows = 2, expected_cols = 4)
