@@ -1,5 +1,12 @@
 context("stats-nls")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
+skip_if_not_installed("MASS")
+
 fit <- nls(
   wt ~ a + b * mpg + c / disp,
   data = mtcars,
@@ -15,32 +22,27 @@ test_that("nls tidier arguments", {
 })
 
 test_that("tidy.nls", {
-  
   td <- tidy(fit, conf.int = TRUE)
-  tdq <- tidy(fit, conf.int = TRUE, quick = TRUE)
-  
   check_tidy_output(td)
-  check_tidy_output(tdq)
   check_dims(td, 3, 7)
-  
+
   expect_equal(td$term, c("a", "b", "c"))
 })
 
 test_that("glance.nls", {
   gl <- glance(fit)
   check_glance_outputs(gl)
-  check_dims(gl, expected_cols = 8)
+  check_dims(gl, expected_cols = 9)
 })
 
 test_that("augment.nls", {
-  
   check_augment_function(
     aug = augment.nls,
     model = fit,
     data = mtcars,
     newdata = mtcars
   )
-  
+
   check_augment_function(
     aug = augment.nls,
     model = fit2,
