@@ -1,5 +1,10 @@
 context("survival-survdiff")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("survival")
 library(survival)
 
@@ -10,8 +15,8 @@ fit3 <- survdiff(
   data = lung
 )
 
-expect <- survexp(
-  futime ~ ratetable(
+expect <- survexp(futime ~ 1,
+  rmap = list(
     age = (accept.dt - birth.dt),
     sex = 1,
     year = accept.dt,
@@ -36,12 +41,16 @@ test_that("tidy.survdiff", {
   td3 <- tidy(fit3)
   td4 <- tidy(fit4)
   td5 <- tidy(fit5)
-  
-  check_tidy_output(td)
-  check_tidy_output(td2)
-  check_tidy_output(td3)
+
+  # The output from tidy.survdiff uses variable names as column names because
+  # the output contains a row for each level of the (statistical) factor.  This
+  # output meets the criteria for 'tidy' data.  Therefore, strict may be
+  # set to FALSE to allow these tests to pass.
+  check_tidy_output(td, strict = FALSE)
+  check_tidy_output(td2, strict = FALSE)
+  check_tidy_output(td3, strict = FALSE)
   check_tidy_output(td4)
-  check_tidy_output(td5)
+  check_tidy_output(td5, strict = FALSE)
 })
 
 test_that("glance.survdiff", {
@@ -50,7 +59,6 @@ test_that("glance.survdiff", {
   gl3 <- glance(fit3)
   gl4 <- glance(fit4)
   gl5 <- glance(fit5)
-  
+
   check_glance_outputs(gl, gl2, gl3, gl4, gl5)
 })
-
